set numPalettes 0

# --------------------------------------------------------------------------
# Starting with Tcl 8.x, the BLT commands are stored in their own 
# namespace called "blt".  The idea is to prevent name clashes with
# Tcl commands and variables from other packages, such as a "table"
# command in two different packages.  
#
# You can access the BLT commands in a couple of ways.  You can prefix
# all the BLT commands with the namespace qualifier "blt::"
#  
#    blt::graph .g
#    blt::table . .g -resize both
# 
# or you can import all the command into the global namespace.
#
#    namespace import blt::*
#    graph .g
#    table . .g -resize both
#
# --------------------------------------------------------------------------
if { $tcl_version >= 8.0 } {
    namespace import blt::*
    namespace import -force blt::tile::*
}
source _demo.tcl

proc ShowPalette { colors } {
    global numPalettes
    set top ".colormap[incr numPalettes]"
    toplevel $top
    set col 0
    set row 0
    foreach {color pixel} $colors {
	label $top.l($row,$col) -text "$color $pixel" -bg $color
	table $top $row,$col $top.l($row,$col)
	incr col 
	if { $col == 8 } {
	    incr row
	    set col 0
	}
    }
}

update
ShowPalette [winop colormap .]
